Struct egui_ash::EguiCommand
source · pub struct EguiCommand { /* private fields */ }Expand description
command recorder to record egui draw commands.
if you recreate swapchain, you must call update_swapchain method.
You also must call update_swapchain method when first time to record commands.
Implementations
sourceimpl EguiCommand
impl EguiCommand
sourcepub fn update_swapchain(&mut self, info: SwapchainUpdateInfo)
pub fn update_swapchain(&mut self, info: SwapchainUpdateInfo)
You must call this method once when first time to record commands and when you recreate swapchain.
sourcepub fn record(self, cmd: CommandBuffer, swapchain_index: usize)
pub fn record(self, cmd: CommandBuffer, swapchain_index: usize)
record commands to command buffer.